# Autogenerated by nbdev

d = { 'settings': { 'branch': 'main',
                'doc_baseurl': '/adviz',
                'doc_host': 'https://eliasdabbas.github.io',
                'git_url': 'https://github.com/eliasdabbas/adviz',
                'lib_path': 'adviz'},
  'syms': { 'adviz.core': {'adviz.core.foo': ('core.html#foo', 'adviz/core.py')},
            'adviz.status_codes': {'adviz.status_codes.status_codes': ('status_codes.html#status_codes', 'adviz/status_codes.py')},
            'adviz.value_counts_plus': { 'adviz.value_counts_plus.value_counts_plus': ( 'value_counts_plus.html#value_counts_plus',
                                                                                        'adviz/value_counts_plus.py')}}}
